@@ -3,7 +3,7 @@ package CHI::Cascade;
 use strict;
 use warnings;
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 use Carp;
 
@@ -301,6 +301,74 @@ to small expsnsive tasks and to describe dependencies for cache items.
 This module is experimental yet. I plan to improve it near time but some things
 already work. You can take a look for t/* tests as examples.
 
+=head1 CONSTRUCTOR
+
+=over
+
+=item $cascade = CHI::Cascade->new( %options )
+
+This method constructs a new C<CHI::Cascade> object and returns it.
+Key/value pair arguments may be provided to set up the initial state.
+Now there is only one option: I<chi> - instance of L<CHI> object.
+
+=back
+
+=head1 METHODS
+
+=over
+
+=item rule( %options )
+
+To add new rule to C<CHI::Cascade> object. All rules should be added before first
+L</run> method
+
+The keys of %options are:
+
+=over
+
+=item target
+
+A target for L</run> and for searching of L</depends>. It can be as scalar text
+or C<Regexp> object created through C<qr//>
+
+=item depends
+
+The list or a scalar value of dependencies - the list of targets which
+the current rule is dependent. Each item can be scalar value (exactly matched
+target) or code reference which will be executed during matching of target.
+A code subroutine will get a parameters from C<=~> operator against C<target>
+matching by C<qr//> operator(not tested while) - please see the section
+L</EXAMPLE> for this example.
+
+=item code
+
+The code reference for computing a value of this target. Will be executed if no
+value in cache for this target or any dependence or dependences of dependences
+and so on will be recomputed. This subroutine will get parameters: $_[0] - flat
+text of current target and hashref of values of dependencies. This module should
+guarantee that values of dependencies will be valid values even if value is
+C<undef>. This code can return C<undef> value as a valid code return but author
+doesn't recommend it. If C<CHI::Cascade> could not get a valid values of all
+dependencies of current target before execution of this code the last will not
+be executed (The C<run> will return C<undef>).
+
+=back
+
+=item run( $target )
+
+This method makes a cascade computing if need and returns value for this target
+If any dependence of this target of any dependencies of dependencies were
+recomputed this target will be recomputed too.
+
+=item touch( $target )
+
+This method refreshes the time of this target. Here is analogy with L<touch>
+utility of Unix and behaviour as L<make> after it. After L</touch> all targets
+are dependent from this target will be recomputed at next L</run> with
+an appropriate ones.
+
+=back
+
 =head1 STATUS
 
 This module is experimental and not finished for new features ;-)
